@@ -4,11 +4,13 @@ from django.utils.translation import (ugettext_lazy as _, ugettext)
 from django.contrib.auth.models import User
 from django.dispatch import Signal
 
-vote_changed= Signal(providing_args=["voter", "object"])
+vote_changed = Signal(providing_args=["voter", "object"])
 
 _vote_models = {}
 
 # Managers --------------------------------------------------------------------
+
+
 class ObjectsWithScoresManager(models.Manager):
     """
     Returns objects with their scores
@@ -21,8 +23,23 @@ class ObjectsWithScoresManager(models.Manager):
             )
         )
 
+
+class SortByScoresManager(models.Manager):
+    """
+    Returns objects with their scores and orders them by value (1,0,-1)
+    """
+    def get_query_set(self):
+        from qhonuskan_votes.utils import SumWithDefault
+        return super(SortByScoresManager, self).get_query_set().annotate(
+            vote_score=SumWithDefault(
+                '%svote__value' % self.model._meta.module_name, default=0
+            )
+        ).order_by('-vote_score')
+
+
 # Fields ----------------------------------------------------------------------
 
+
 class VotesField(object):
     """
     Usage:
@@ -91,19 +108,15 @@ class VotesField(object):
                 verbose_name_plural = _('Votes')
 
             def save(self, *args, **kwargs):
-                changed = False
-                if self.pk:
+
+                if self.pk is not None:
                     orig_vote = Vote.objects.get(pk=self.pk)
                     if orig_vote.value != self.value:
-                        changed = True
+                        vote_changed.send(sender=self)
                 else:
-                    changed = True
-
+                    vote_changed.send(sender=self)
                 super(Vote, self).save(*args, **kwargs)
 
-                if vote_changed:
-                    vote_changed.send(sender=self)
-            
             def delete(self, *args, **kwargs):
                 super(Vote, self).delete(*args, **kwargs)
                 vote_changed.send(sender=self)
@@ -120,7 +133,6 @@ class VotesField(object):
             def get_model_name(self):
                 return '%s.%s' % (self._meta.app_label, self._meta.object_name)
 
-
         class VoteFieldDescriptor(object):
             def __init__(self):
                 pass
