@@ -1,6 +1,4 @@
-from django.contrib.auth.models import User
 from qhonuskan_votes.utils import get_vote_model, SumWithDefault
-from django.db.models import Sum
 from django.utils import simplejson
 from django.http import HttpResponse, HttpResponseRedirect
 from django.views.decorators.csrf import csrf_exempt
@@ -34,6 +32,7 @@ def _api_view(func):
             return HttpResponse(status=403)
     return view
 
+
 @csrf_exempt
 @_api_view
 def vote(request, model, object_id, value):
@@ -53,7 +52,7 @@ def vote(request, model, object_id, value):
         return HttpResponse(status=400)
 
     try:
-         vote_instance = model.objects.get(
+        vote_instance = model.objects.get(
             object__id=object_id,
             voter=request.user
         )
